summaryrefslogtreecommitdiffstats
path: root/alacritty_terminal/src/term/color.rs
diff options
context:
space:
mode:
Diffstat (limited to 'alacritty_terminal/src/term/color.rs')
-rw-r--r--alacritty_terminal/src/term/color.rs6
1 files changed, 4 insertions, 2 deletions
diff --git a/alacritty_terminal/src/term/color.rs b/alacritty_terminal/src/term/color.rs
index 1cfdec6b..3c545b28 100644
--- a/alacritty_terminal/src/term/color.rs
+++ b/alacritty_terminal/src/term/color.rs
@@ -7,12 +7,14 @@ use serde::de::{Error as _, Visitor};
use serde::{Deserialize, Deserializer, Serialize};
use serde_yaml::Value;
+use alacritty_config_derive::SerdeReplace;
+
use crate::ansi::NamedColor;
/// Number of terminal colors.
pub const COUNT: usize = 269;
#[derive(Debug, Eq, PartialEq, Copy, Clone, Default, Serialize)]
pub struct Rgb {
pub r: u8,
pub g: u8,
@@ -170,7 +172,7 @@ impl FromStr for Rgb {
}
/// RGB color optionally referencing the cell's foreground or background.
#[derive(Copy, Clone, Debug, PartialEq, Eq)]
pub enum CellRgb {
CellForeground,
CellBackground,
@@ -7,12 +7,14 @@ use serde::de::{Error as _, Visitor};
/// Number of terminal colors.
pub const COUNT: usize = 269;
-#[derive(Debug, Eq, PartialEq, Copy, Clone, Default, Serialize)]
+#[derive(SerdeReplace, Debug, Eq, PartialEq, Copy, Clone, Default, Serialize)]
pub struct Rgb {
pub r: u8,
@@ -170,7 +172,7 @@ impl FromStr for Rgb {
}
/// RGB color optionally referencing the cell's foreground or background.
-#[derive(Copy, Clone, Debug, PartialEq, Eq)]
+#[derive(SerdeReplace, Copy, Clone, Debug, PartialEq, Eq)]
pub enum CellRgb {
CellForeground,